/* 27-June-00 AT  added default radius and Ltruscale for BCEA projection */
#ifdef __cplusplus
extern "C" {
#endif

#define PGSd_BCEA 98
#define PGSd_DEFAULT_BCEA_RADIUS 6371228.0 /*Earth radius for BCEA projection*/
#define PGSd_DEFAULT_BCEA_LTRUESCALE 30.0  /*Latitude of true scale */

#ifdef __cplusplus
}
#endif
